.. _vtksuite:

vtksuite.py
===========

This Python module contains one routine to convert from exadata to vtk data
structure.

.. warning::

   The module is experimental in nature and may have some rough edges.

-------------------------------------------------------------------------------

.. _vtksuite-contents:

Contents of vtksuite.py
-----------------------

.. automodule:: pymech.vtksuite
